Plan History Tab
----------------

Shows recently executed plans.

Copy to Queue:
    Copy selected plans to the end of the queue.
Deselect All:
    Deselect all plans.
Clear History:
    Clear the plan history.

.. attention::
    Clearing the plan history is irreversible, and will remove the plans from the history permanently.
    The plans and data will not be deleted from Tiled, but it will no longer be possible to copy the old plans to
    the queue to re-run easily.